@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.09';
+our $VERSION = '0.100';
 use 5.006;
 use strict;
 use warnings;
@@ -88,6 +88,7 @@ sub run {
 	my ($session) = $j->_dispatch($auth, $pkg->new());
 	my $req = $j->params->req;
 	$req =~ /^([a-z][0-9a-zA-Z_]{1,31})$/; $req = $1 // '';
+	$req = $j->{_application}->preprocess_req($req, $j) if $j->{_application}->can('preprocess_req');
 	if (!$req || !$session || $PRIVATE{$req}) {
 		$j->response->raiseError('Invalid request', 400);
 		return $j->_response($j->response);
@@ -96,7 +97,7 @@ sub run {
 	$j->response->authenticated = \1;
 	$j->session = $session;
 
-	my ($login, $logout) = (
+	($j->is_login, $j->is_logout) = (
 		$j->{_login} eq $req,
 		$j->{_logout} eq $req
 	);
@@ -105,20 +106,20 @@ sub run {
 	
 	return $j->_response($j->response) if $j->response->error;
 
-	$j->session = $out if ( $login || $logout );
+	$j->session = $out if ( $j->is_login || $j->is_logout );
 
 	($j->session) = $j->_dispatch($auth, $j, $j->session)  if $j->response->authenticated;
 
-	if ((!$j->response->authenticated || !$j->session) && !($login || $logout)) {
+	if ((!$j->response->authenticated || !$j->session) && !($j->is_login || $j->is_logout)) {
 		$j->response->raiseError('Unauthenticated during the request', 400);
 		return $j->_response($j->response);
 	}
 
 	my $cookie = {
-		value => $logout ? "" : $j->sid,
+		value => $j->is_logout ? "" : $j->sid,
 		path  => $j->request->uri,
 		secure => !$j->{_insecure_session},
-		expires => $logout ? time : ((ref $j->session && $j->session->expires) || time + 24 * 60 * 60),
+		expires => $j->is_logout ? time : ((ref $j->session && $j->session->expires) || time + 24 * 60 * 60),
 	};
 
 	return $j->_response($j->response, $cookie);
@@ -271,7 +272,7 @@ Terse - lightweight JSON APIs.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.100
 
 =cut
 
