@@ -8,6 +8,16 @@ use B 'svref_2object';
 our %HTTP;
 BEGIN { %HTTP = map { $_ => 1 } qw/get post put delete connect head options trace patch/; }
 
+sub new {
+	my ($pkg, @args) = @_;
+	my $self = $pkg->SUPER::new(@args);
+	(my $namespace = $pkg) =~ s/^.*Controller:://;
+	$namespace =~ s/\:\:/\//g;
+	$self->namespace = lc( $namespace );
+	$self->build_controller() if ($self->can('build_controller'));
+	return $self;
+}
+
 sub MODIFY_CODE_ATTRIBUTES {
 	my ($package, $coderef, @attributes, @disallowed) = @_;
 	my $name = svref_2object($coderef)->GV->NAME;
@@ -114,7 +124,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.100
 
 =cut
 
