@@ -10,7 +10,7 @@ sub login :any {
 	return 1;
 }
 
-sub auth_prevent :req(auth) :any {
+sub auth_prevent :any(auth) {
 	return 0;
 }
 
@@ -18,15 +18,15 @@ sub auth_okay :req(auth) :get :post  {
 	return 1;
 }
 
-sub hello :req(hello_world) :any {
+sub hello :any(hello_world) {
 	$_[1]->response->hello = "world";
 }
 
-sub hello_get :req(hello_world) :get {
+sub hello_get :get(hello_world) {
 	$_[1]->response->hello = "world 2";
 }
 
-sub hello_get_with_params :req(hello_world) :get :params(test => 'okay') {
+sub hello_get_with_params :get(hello_world) :params(test => 'okay') {
 	$_[1]->response->hello = "world 3";
 }
 
